# TNFR Validation — Canonical Module Hub (Single Source of Truth)

English-only hub for validators and checks.

- Canonical physics/invariants: `AGENTS.md`
- Grammar: `UNIFIED_GRAMMAR_RULES.md`

## Scope
- Input validation, invariant checks, grammar compliance routines
